@@ -110,10 +110,21 @@ def getJobDetail(jobId, descOnly):
     }]
 
 
+
+
     print('%s' % bold(magenta('Job:')))
     list2table.print_table(t, cols=['a', 'b', 'c'], show_no=False, show_header=False)
 
 
+    # notification
+    if desc.get('Notification').get('Topic').get('Events'):
+        print('  %s' % (blue('Notification Topic')))
+        print('    %s: %s' % (blue('Endpoint'),  desc.get('Notification').get('Topic').get('Endpoint')))
+        print('    %s: %s' % (blue('Name'),  desc.get('Notification').get('Topic').get('Name')))
+        print('    %s: %s' % (blue('Events'), ','.join(desc.get('Notification').get('Topic').get('Events'))))
+
+
+
     # description
     if desc.get('Description'):
         print('  %s: %s' % (blue('Description'), desc.get('Description') or ''))
